==> 0.0.6.tar.gz: example/lib/pages/profile/component/profilePanel.dart <==
import 'package:flutter/cupertino.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_user_full_info.dart';
import 'package:tencent_im_sdk_plugin_example/common/avatar.dart';
import 'package:tencent_im_sdk_plugin_example/common/colors.dart';

class ProfilePanel extends StatelessWidget {
  ProfilePanel(this.userInfo);
  final V2TimUserFullInfo userInfo;
  @override
  Widget build(BuildContext context) {
    if (userInfo == null) {
      return Container(
        height: 112,
      );
    }
    return Container(
      height: 112,
      padding: EdgeInsets.all(16),
      color: CommonColors.getWitheColor(),
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.center,
        children: [
          Container(
            width: 80,
            child: Avatar(
              avtarUrl: userInfo.faceUrl == null || userInfo.faceUrl == ''
                  ? 'images/logo.png'
                  : userInfo.faceUrl,
              width: 80,
              height: 80,
              radius: 9.6,
            ),
          ),
          Expanded(
            child: Container(
              margin: EdgeInsets.only(left: 12),
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  // 昵称
                  Container(
                    height: 34,
                    child: Text(
                      (userInfo.nickName == null || userInfo.nickName == '')
                          ? userInfo.userID
                          : userInfo.nickName,
                      style: TextStyle(
                        fontSize: 24,
                        color: CommonColors.getTextBasicColor(),
                      ),
                    ),
                  ),
                  Container(
                    height: 23,
                    child: Text(
                      '用户ID：${userInfo.userID}',
                      style: TextStyle(
                        fontSize: 14,
                        color: CommonColors.getTextWeakColor(),
                      ),
                    ),
                  ),
                  Container(
                    height: 23,
                    child: Text(
                      '好友备注：${userInfo.selfSignature}',
                      style: TextStyle(
                        fontSize: 14,
                        color: CommonColors.getTextWeakColor(),
                      ),
                    ),
                  ),
                ],
              ),
            ),
          )
        ],
      ),
    );
  }
}

==> 0.0.10.tar.gz: example/lib/pages/profile/component/profilePanel.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_user_full_info.dart';
import 'package:tencent_im_sdk_plugin_example/common/avatar.dart';
import 'package:tencent_im_sdk_plugin_example/common/colors.dart';

class ProfilePanel extends StatelessWidget {
  ProfilePanel(this.userInfo, this.isSelf);
  final V2TimUserFullInfo userInfo;
  final bool isSelf;
  getSelfSignature() {
    if (userInfo.selfSignature == '' || userInfo.selfSignature == null) {
      return "";
    } else {
      return userInfo.selfSignature;
    }
  }

  hasNickName() {
    return !(userInfo.nickName == '' || userInfo.nickName == null);
  }

  @override
  Widget build(BuildContext context) {
    if (userInfo == null) {
      return Container(
        height: 112,
      );
    }

    return Container(
      height: 112,
      padding: EdgeInsets.all(16),
      color: CommonColors.getWitheColor(),
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.center,
        children: [
          Container(
            width: 80,
            child: Avatar(
              avtarUrl: userInfo.faceUrl == null || userInfo.faceUrl == ''
                  ? 'images/logo.png'
                  : userInfo.faceUrl,
              width: 80,
              height: 80,
              radius: 9.6,
            ),
          ),
          Expanded(
            child: Container(
              margin: EdgeInsets.only(left: 12),
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  // 昵称
                  Container(
                    height: 34,
                    child: Text(
                      (userInfo.nickName == null || userInfo.nickName == '')
                          ? userInfo.userID
                          : userInfo.nickName,
                      style: TextStyle(
                        fontSize: 24,
                        color: CommonColors.getTextBasicColor(),
                      ),
                    ),
                  ),
                  Container(
                    height: 23,
                    child: Text(
                      '用户ID：${userInfo.userID}',
                      style: TextStyle(
                        fontSize: 14,
                        color: CommonColors.getTextWeakColor(),
                      ),
                    ),
                  ),
                  !isSelf
                      ? Container(
                          height: 23,
                          child: Text(
                            '个性签名：${getSelfSignature()}',
                            style: TextStyle(
                              fontSize: 14,
                              color: CommonColors.getTextWeakColor(),
                            ),
                          ),
                        )
                      : Container(),
                ],
              ),
            ),
          )
        ],
      ),
    );
  }
}
